"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { getExerciseById } from "@/services/exercise-service"
import type { Exercise } from "@/types/course"
import Quiz from "@/components/quiz"

export default function ExercisePage({ params }: { params: { id: string } }) {
  const router = useRouter()
  const [exercise, setExercise] = useState<Exercise | null>(null)
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  // Utiliser l'ID de manière sécurisée
  const exerciseId = params.id

  useEffect(() => {
    async function loadExercise() {
      try {
        const data = await getExerciseById(exerciseId)
        if (!data) {
          setError("Exercice non trouvé")
        } else {
          setExercise(data)
        }
      } catch (error) {
        console.error("Erreur lors du chargement de l'exercice:", error)
        setError("Une erreur est survenue lors du chargement de l'exercice")
      } finally {
        setLoading(false)
      }
    }

    loadExercise()
  }, [exerciseId])

  if (loading) {
    return (
      <div className="min-h-screen flex justify-center items-center bg-gray-50">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-blue-500"></div>
      </div>
    )
  }

  if (error || !exercise) {
    return (
      <div className="min-h-screen flex justify-center items-center bg-gray-50">
        <div className="bg-white rounded-lg shadow-md p-8 max-w-md text-center">
          <h2 className="text-2xl font-bold text-red-600 mb-4">Erreur</h2>
          <p className="text-gray-700 mb-6">{error || "Exercice non trouvé"}</p>
          <button onClick={() => router.back()} className="bg-blue-600 hover:bg-blue-700 text-white py-2 px-6 rounded">
            Retour
          </button>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <Quiz title={`Exercice: ${exercise.title}`} questions={exercise.questions} type="exercise" />
    </div>
  )
}
